#
# transistor-micro.R, 30 Jan 22
#
# Data from:
# Cramming more components onto integrated circuits by Gordon E. Moore
#
# https://en.wikipedia.org/wiki/Transistor_count
#

library("colorspace")

par(bty="l")
par(las=1)
par(pch="+")

pal_col=rainbow(4)

tc=read.csv("transistor-micro.csv", as.is=TRUE)


moore=subset(tc, Processor == "Moores_law")
products=subset(tc, (Processor != "Moores_law") & (Year <= 2021))

plot(1, type="n", log="y",
	xaxs="i", yaxs="i",
	xlim=c(1960, 2021), ylim=c(10, 1e11),
	xlab="Year", ylab="Transistors per device")

points(moore$Year, moore$Transistor.count, col=pal_col[1])
points(products$Year, products$Transistor.count, col=pal_col[3])

moore_year=1960:1975
ml_mod=glm(log(Transistor.count) ~ Year, data=moore)
# summary(ml_mod)
pred=predict(ml_mod, newdata=data.frame(Year=moore_year))

lines(moore_year, exp(pred), col=pal_col[2])

prod_mod=glm(log(Transistor.count) ~ Year, data=products)
# summary(prod_mod)
pred=predict(prod_mod)

lines(products$Year, exp(pred), col=pal_col[4])

